<?php
/**
 * Plugin Name: Custom Cookie Notice
 * Description: Выводит настраиваемое всплывающее уведомление о cookies для посетителей сайта.
 * Version: 1.0
 * Author: Alex Haleev
 * Author URI: https://alex-haleev.com
 */

// Функция, добавляющая CSS и JS в футер сайта
function custom_cookie_notice_enqueue_scripts() {
    $textColor = get_option('cookie_notice_text_color', '#ffffff');
    $backgroundColor = get_option('cookie_notice_background_color', '#000000');
    $delay = (int) get_option('cookie_notice_delay', 0) * 1000;

    ?>
    <style>
        #cookie-notice {
            position: fixed;
            bottom: 0;
            width: 100%;
            color: <?php echo $textColor; ?>;
            background: <?php echo $backgroundColor; ?>;
            padding: 20px;
            text-align: center;
            z-index: 10000;
            display: none;
        }

        #cookie-notice button {
            margin-left: 20px;
            padding: 10px 20px;
            cursor: pointer;
        }
    </style>

    <script>
        document.addEventListener('DOMContentLoaded', function() {
            setTimeout(function() {
                var cookieNotice = document.getElementById('cookie-notice');
                var position = '<?php echo get_option('cookie_notice_position', 'bottom'); ?>';

                switch(position) {
                    case 'top':
                        cookieNotice.style.top = '0';
                        break;
                    case 'bottom':
                        cookieNotice.style.bottom = '0';
                        break;
                    case 'left':
                        cookieNotice.style.left = '0';
                        break;
                    case 'right':
                        cookieNotice.style.right = '0';
                        break;
                    case 'center':
                        cookieNotice.style.left = '50%';
                        cookieNotice.style.top = '50%';
                        cookieNotice.style.transform = 'translate(-50%, -50%)';
                        cookieNotice.style.textAlign = 'left';
                        break;
                }

                if (!document.cookie.includes('cookie_notice_status')) {
                    cookieNotice.style.display = 'block';
                }

                document.getElementById('accept-cookies').addEventListener('click', function() {
                    var days = <?php echo (int)get_option('cookie_notice_days', 30); ?>;
                    var date = new Date();
                    date.setTime(date.getTime() + (days * 24 * 60 * 60 * 1000));
                    document.cookie = 'cookie_notice_status=accepted; path=/; expires=' + date.toUTCString();
                    cookieNotice.style.display = 'none';
                });

                document.getElementById('reject-cookies').addEventListener('click', function() {
                    var days = <?php echo (int)get_option('cookie_notice_days', 30); ?>;
                    var date = new Date();
                    date.setTime(date.getTime() + (days * 24 * 60 * 60 * 1000));
                    document.cookie = 'cookie_notice_status=rejected; path=/; expires=' + date.toUTCString();
                    cookieNotice.style.display = 'none';
                });
            }, <?php echo $delay; ?>);
        });
    </script>
    <?php
}
add_action('wp_footer', 'custom_cookie_notice_enqueue_scripts');

// Функция для вывода уведомления на сайт
function custom_cookie_notice() {
    $bannerText = get_option('cookie_notice_banner_text', 'Wir verwenden Cookies, um Ihnen das beste Erlebnis auf unserer Website zu bieten.');
    $acceptButtonText = get_option('cookie_notice_accept_button_text', 'Akzeptieren');
    $rejectButtonText = get_option('cookie_notice_reject_button_text', 'Ablehnen');
    ?>
    <div id="cookie-notice">
        <?php echo $bannerText; ?>
        <button id="accept-cookies"><?php echo $acceptButtonText; ?></button>
        <button id="reject-cookies"><?php echo $rejectButtonText; ?></button>
    </div>
    <?php
}
add_action('wp_footer', 'custom_cookie_notice');

// Добавление страницы настроек в админ-панель
function custom_cookie_notice_menu() {
    add_options_page(
        'Настройки уведомления о cookies',
        'Custom Cookie Notice',
        'manage_options',
        'custom-cookie-notice',
        'custom_cookie_notice_settings_page'
    );
}
add_action('admin_menu', 'custom_cookie_notice_menu');

// Содержимое страницы настроек
function custom_cookie_notice_settings_page() {
    ?>
    <div class="wrap">
        <h2>Настройки уведомления о cookies</h2>
        <form method="post" action="options.php">
            <?php settings_fields('custom-cookie-notice-settings-group'); ?>
            <?php do_settings_sections('custom-cookie-notice-settings-group'); ?>
            <table class="form-table">
                <tr valign="top">
                <th scope="row">Количество дней для хранения выбора пользователя</th>
                <td>
                    <input type="number" name="cookie_notice_days" value="<?php echo esc_attr(get_option('cookie_notice_days', 30)); ?>" />
                </td>
                </tr>

                <tr valign="top">
                <th scope="row">Позиция уведомления</th>
                <td>
                    <select name="cookie_notice_position">
                        <option value="top" <?php selected(get_option('cookie_notice_position', 'bottom'), 'top'); ?>>Вверху</option>
                        <option value="bottom" <?php selected(get_option('cookie_notice_position', 'bottom'), 'bottom'); ?>>Внизу</option>
                        <option value="left" <?php selected(get_option('cookie_notice_position', 'bottom'), 'left'); ?>>Слева</option>
                        <option value="right" <?php selected(get_option('cookie_notice_position', 'bottom'), 'right'); ?>>Справа</option>
                        <option value="center" <?php selected(get_option('cookie_notice_position', 'bottom'), 'center'); ?>>По центру</option>
                    </select>
                </td>
                </tr>

                <tr valign="top">
                <th scope="row">Цвет текста</th>
                <td>
                    <input type="color" name="cookie_notice_text_color" value="<?php echo esc_attr(get_option('cookie_notice_text_color', '#ffffff')); ?>" />
                </td>
                </tr>

                <tr valign="top">
                <th scope="row">Цвет фона</th>
                <td>
                    <input type="color" name="cookie_notice_background_color" value="<?php echo esc_attr(get_option('cookie_notice_background_color', '#000000')); ?>" />
                </td>
                </tr>

                <tr valign="top">
                <th scope="row">Задержка показа уведомления (в секундах)</th>
                <td>
                    <input type="number" name="cookie_notice_delay" value="<?php echo esc_attr(get_option('cookie_notice_delay', 0)); ?>" />
                </td>
                </tr>

                <tr valign="top">
                <th scope="row">Текст баннера</th>
                <td>
                    <input type="text" name="cookie_notice_banner_text" value="<?php echo esc_attr(get_option('cookie_notice_banner_text', 'Wir verwenden Cookies, um Ihnen das beste Erlebnis auf unserer Website zu bieten.')); ?>" />
                </td>
                </tr>

                <tr valign="top">
                <th scope="row">Текст кнопки принятия</th>
                <td>
                    <input type="text" name="cookie_notice_accept_button_text" value="<?php echo esc_attr(get_option('cookie_notice_accept_button_text', 'Akzeptieren')); ?>" />
                </td>
                </tr>

                <tr valign="top">
                <th scope="row">Текст кнопки отклонения</th>
                <td>
                    <input type="text" name="cookie_notice_reject_button_text" value="<?php echo esc_attr(get_option('cookie_notice_reject_button_text', 'Ablehnen')); ?>" />
                </td>
                </tr>
            </table>

            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}

// Регистрация настроек
function custom_cookie_notice_settings() {
    register_setting('custom-cookie-notice-settings-group', 'cookie_notice_days');
    register_setting('custom-cookie-notice-settings-group', 'cookie_notice_position');
    register_setting('custom-cookie-notice-settings-group', 'cookie_notice_text_color');
    register_setting('custom-cookie-notice-settings-group', 'cookie_notice_background_color');
    register_setting('custom-cookie-notice-settings-group', 'cookie_notice_delay');
    register_setting('custom-cookie-notice-settings-group', 'cookie_notice_banner_text');
    register_setting('custom-cookie-notice-settings-group', 'cookie_notice_accept_button_text');
    register_setting('custom-cookie-notice-settings-group', 'cookie_notice_reject_button_text');
}
add_action('admin_init', 'custom_cookie_notice_settings');
?>
